@@ -1,6 +1,5 @@
 import warnings
 
-from .api.emails import Emails
 from .api.users import Users
 from .api.magic_links import MagicLinks
 
@@ -26,7 +25,6 @@ class Client:
 
         self.Users = Users(self)
         self.MagicLinks = MagicLinks(self)
-        self.Emails = Emails(self)
 
     @property
     def base_url(self):
